@@ -44,6 +44,7 @@ pub struct ExitEscrowEvent {
 /// Event called in [locked_voter::lock].
 pub struct LockEvent {
     /// The locker of the [Escrow]
+    #[index]
     pub locker: Pubkey,
     /// The owner of the [Escrow].
     #[index]
@@ -57,3 +58,27 @@ pub struct LockEvent {
     /// Timestamp of the event.
     pub timestamp: i64,
 }
+
+#[event]
+/// Event called in [locked_voter::approve_program_lock_privilege].
+pub struct ApproveLockPrivilegeEvent {
+    /// The [Locker].
+    #[index]
+    pub locker: Pubkey,
+    /// ProgramId approved to make CPI calls to [locked_voter::lock].
+    pub program_id: Pubkey,
+    /// Timestamp of the event.
+    pub timestamp: i64,
+}
+
+#[event]
+/// Event called in [locked_voter::revoke_program_lock_privilege].
+pub struct RevokeLockPrivilegeEvent {
+    /// The [Locker].
+    #[index]
+    pub locker: Pubkey,
+    /// ProgramId approved to make CPI calls to [locked_voter::lock].
+    pub program_id: Pubkey,
+    /// Timestamp of the event.
+    pub timestamp: i64,
+}
